deep\_translator package
========================

Submodules
----------

deep\_translator.cli module
---------------------------

.. automodule:: deep_translator.cli
    :members:
    :undoc-members:
    :show-inheritance:

deep\_translator.constants module
---------------------------------

.. automodule:: deep_translator.constants
    :members:
    :undoc-members:
    :show-inheritance:

deep\_translator.deep\_translator module
----------------------------------------

.. automodule:: deep_translator.deep_translator
    :members:
    :undoc-members:
    :show-inheritance:

deep\_translator.exceptions module
----------------------------------

.. automodule:: deep_translator.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

deep\_translator.models module
------------------------------

.. automodule:: deep_translator.models
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: deep_translator
    :members:
    :undoc-members:
    :show-inheritance:
